.TH QUICKPLOT PUBLIC 
.UC 4
.SH NAME
quickplot \- make a printable ascii approximation of a plot stream
.SH SYNOPSIS
.B quickplot
[ option ] ...
[ file ]
[ option ] ...
[ file ]  ...
.SH DESCRIPTION
.I Quickplot
accepts a plot stream as produced by the plot(3) functions and
generates on the standard output a byte stream which is a printable
ascii approximation of the plot, suitable for viewing on an ascii
terminal or printing device.  Quickplot is useful for previewing
plots on your terminal before sending to a plotting device.
.PP
.I Quickplot
consults the termcap database for your terminal type (as given by
the TERM environment variable) and attempts to size the plot to
fill your screen.  The terminal type may be overridden by specifying
a terminal type on the command line or by specifying the rows and
columns desired (see OPTIONS below).
.PP
If no file arguments are given,
.I quickplot
reads from the standard input.
If file arguments are given, an argument consisting of the single
character '-' will be replaced by the standard input.

.SH OPTIONS
.IP "-T \fIterm\fP" 15n
make a plot suitable for terminal given by \fIterm\fP.
.IP "-H \fIrows\fP" 15n
map the plot into \fIrows\fP rows, instead of the rows given by termcap.
.IP "-W \fIcols\fP" 15n
map the plot into \fIcols\fP cols, instead of the cols given by termcap.
.IP "-s[xy] \fIfactor\fP" 15n
set an overall scale factor.  The plot is magnified by the scale factor
(but may be truncated if the screen is too small).  If \fIx\fP or
\fIy\fP is given, the scale factor will be applied in the indicated
direction only.
.IP "-X \fIcols\fP" 15n
move the plot right \fIcols\fP cols (negative \fIcols\fP moves left).
.IP "-Y \fIrows\fP" 15n
move the plot up \fIrows\fP  rows (negative \fIrows\fP moves down).
.IP "-c \fIchar\fP" 15n
The plotting character (default upper case 'X') will be replaced by
\fIchar\fP
.IP "-e" 15n
force an erase command between plot files
.IP "-N" 15n
suppress erase commands
.IP "-r" 15n
rotate the plot 90 degrees counter-clockwise
.IP "-d num" 15n
set debugging level to
.I num
(debugging is conditionally compiled; this may have no effect).
The most useful setting is '1', which causes
.I quickplot
to print the plot(3) commands as it interprets them, with
arguments scaled to final values.
The plot is still generated.
.SH NOTE BENE
.I Quickplot
is unlike most plot filters in that it does not map your
plot space specifically into a square plotting area; instead, it
attempts to obtain maximum resolution by mapping the plot into the
full screen.
Since most terminals have many more columns than rows, most plots
will be "distorted" (a square box will plot as a rectangle).
.PP
Data outside the plot area will be truncated (plotted at the maximum
plot point) and the normal plot character will be replaced by the
character '@' (which does not change if you select '@' as the plot
character).
.PP
IF MORE THAN ONE PLOT FILE IS GIVEN AS ARGUMENT,
.I quickplot
will pause
.B SILENTLY
between plots (unless standard output and standard error have been
re-directed) and wait for a single carriage return before proceeding
to the next plot.
.SH DIAGNOSTICS
\'Bad input data: cmd %o' if an unrecognized plot command is received.
May happen if labels contain newlines, or plot stream files
are corrupted.	Scanning will continue.
Premature EOF while reading data for a command will generate an
appropriate error and the program will quit.
.SH "SEE ALSO"
lplot(1)
.SH AUTHOR
Duane Hesser (sysad@teltone)
.SH BUGS
Resolution is understandably poor.
Plots are squashed vertically.
.PP
.I Quickplot
attempts to identify dotted, dashed, etc. lines by plotting alternate
characters in a line as a small integer digit representing the line
type.  For short line segments, this doesn't work very well, since there
is no memory of the previous line segment.
